summaryrefslogtreecommitdiffstats
path: root/src/doc.js
diff options
context:
space:
mode:
authorwout <wout@impinc.co.uk>2014-06-21 20:32:28 +0200
committerwout <wout@impinc.co.uk>2014-06-21 20:32:28 +0200
commit629a01b3bbf057eae7e0599433bbbcb28acd8587 (patch)
treec6ce43e4bb28e61885921d19ae99726ea93828c0 /src/doc.js
parent19b6fd4338246d1fd9ca4806e57c7aebcec63826 (diff)
downloadsvg.js-629a01b3bbf057eae7e0599433bbbcb28acd8587.tar.gz
svg.js-629a01b3bbf057eae7e0599433bbbcb28acd8587.zip
Various reference fixes
Diffstat (limited to 'src/doc.js')
-rwxr-xr-xsrc/doc.js3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/doc.js b/src/doc.js
index 54b7c70..1a025f3 100755
--- a/src/doc.js
+++ b/src/doc.js
@@ -15,10 +15,11 @@ SVG.Doc = SVG.invent({
element.appendChild(this.node)
}
/* set svg element attributes */
this
.attr({ xmlns: SVG.ns, version: '1.1', width: '100%', height: '100%' })
.attr('xmlns:xlink', SVG.xlink, SVG.xmlns)
+ .defs()
}
// Inherit from
@@ -15,10 +15,11 @@ SVG.Doc = SVG.invent({
element.appendChild(this.node)
}
- /* set svg element attributes */
+ /* set svg element attributes and ensure defs node */
this
.attr({ xmlns: SVG.ns, version: '1.1', width: '100%', height: '100%' })